# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RemoteAdbDataSourceArgs', 'RemoteAdbDataSource']

@pulumi.input_type
class RemoteAdbDataSourceArgs:
    def __init__(__self__, *,
                 local_database: pulumi.Input[str],
                 local_db_instance_id: pulumi.Input[str],
                 manager_user_name: pulumi.Input[str],
                 manager_user_password: pulumi.Input[str],
                 remote_database: pulumi.Input[str],
                 remote_db_instance_id: pulumi.Input[str],
                 user_name: pulumi.Input[str],
                 user_password: pulumi.Input[str],
                 data_source_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a RemoteAdbDataSource resource.
        :param pulumi.Input[str] local_database: The database of the local instance which connection data.
        :param pulumi.Input[str] local_db_instance_id: The instanceId of the local instance which connection data.
        :param pulumi.Input[str] manager_user_name: The Management user name of the local instance.
        :param pulumi.Input[str] manager_user_password: Password of the Manager user of the local instance
        :param pulumi.Input[str] remote_database: The database of the remote instance which provide data.
        :param pulumi.Input[str] remote_db_instance_id: The instanceId of the remote instance which provide data.
        :param pulumi.Input[str] user_name: The user name used to connect to the remote instance
        :param pulumi.Input[str] user_password: The user password used to connect to the remote instance
        :param pulumi.Input[str] data_source_name: Data Source Name
        """
        pulumi.set(__self__, "local_database", local_database)
        pulumi.set(__self__, "local_db_instance_id", local_db_instance_id)
        pulumi.set(__self__, "manager_user_name", manager_user_name)
        pulumi.set(__self__, "manager_user_password", manager_user_password)
        pulumi.set(__self__, "remote_database", remote_database)
        pulumi.set(__self__, "remote_db_instance_id", remote_db_instance_id)
        pulumi.set(__self__, "user_name", user_name)
        pulumi.set(__self__, "user_password", user_password)
        if data_source_name is not None:
            pulumi.set(__self__, "data_source_name", data_source_name)

    @property
    @pulumi.getter(name="localDatabase")
    def local_database(self) -> pulumi.Input[str]:
        """
        The database of the local instance which connection data.
        """
        return pulumi.get(self, "local_database")

    @local_database.setter
    def local_database(self, value: pulumi.Input[str]):
        pulumi.set(self, "local_database", value)

    @property
    @pulumi.getter(name="localDbInstanceId")
    def local_db_instance_id(self) -> pulumi.Input[str]:
        """
        The instanceId of the local instance which connection data.
        """
        return pulumi.get(self, "local_db_instance_id")

    @local_db_instance_id.setter
    def local_db_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "local_db_instance_id", value)

    @property
    @pulumi.getter(name="managerUserName")
    def manager_user_name(self) -> pulumi.Input[str]:
        """
        The Management user name of the local instance.
        """
        return pulumi.get(self, "manager_user_name")

    @manager_user_name.setter
    def manager_user_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "manager_user_name", value)

    @property
    @pulumi.getter(name="managerUserPassword")
    def manager_user_password(self) -> pulumi.Input[str]:
        """
        Password of the Manager user of the local instance
        """
        return pulumi.get(self, "manager_user_password")

    @manager_user_password.setter
    def manager_user_password(self, value: pulumi.Input[str]):
        pulumi.set(self, "manager_user_password", value)

    @property
    @pulumi.getter(name="remoteDatabase")
    def remote_database(self) -> pulumi.Input[str]:
        """
        The database of the remote instance which provide data.
        """
        return pulumi.get(self, "remote_database")

    @remote_database.setter
    def remote_database(self, value: pulumi.Input[str]):
        pulumi.set(self, "remote_database", value)

    @property
    @pulumi.getter(name="remoteDbInstanceId")
    def remote_db_instance_id(self) -> pulumi.Input[str]:
        """
        The instanceId of the remote instance which provide data.
        """
        return pulumi.get(self, "remote_db_instance_id")

    @remote_db_instance_id.setter
    def remote_db_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "remote_db_instance_id", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Input[str]:
        """
        The user name used to connect to the remote instance
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> pulumi.Input[str]:
        """
        The user password used to connect to the remote instance
        """
        return pulumi.get(self, "user_password")

    @user_password.setter
    def user_password(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_password", value)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> Optional[pulumi.Input[str]]:
        """
        Data Source Name
        """
        return pulumi.get(self, "data_source_name")

    @data_source_name.setter
    def data_source_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_name", value)


@pulumi.input_type
class _RemoteAdbDataSourceState:
    def __init__(__self__, *,
                 data_source_name: Optional[pulumi.Input[str]] = None,
                 local_database: Optional[pulumi.Input[str]] = None,
                 local_db_instance_id: Optional[pulumi.Input[str]] = None,
                 manager_user_name: Optional[pulumi.Input[str]] = None,
                 manager_user_password: Optional[pulumi.Input[str]] = None,
                 remote_adb_data_source_id: Optional[pulumi.Input[int]] = None,
                 remote_database: Optional[pulumi.Input[str]] = None,
                 remote_db_instance_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 user_name: Optional[pulumi.Input[str]] = None,
                 user_password: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RemoteAdbDataSource resources.
        :param pulumi.Input[str] data_source_name: Data Source Name
        :param pulumi.Input[str] local_database: The database of the local instance which connection data.
        :param pulumi.Input[str] local_db_instance_id: The instanceId of the local instance which connection data.
        :param pulumi.Input[str] manager_user_name: The Management user name of the local instance.
        :param pulumi.Input[str] manager_user_password: Password of the Manager user of the local instance
        :param pulumi.Input[int] remote_adb_data_source_id: The first ID of the resource
        :param pulumi.Input[str] remote_database: The database of the remote instance which provide data.
        :param pulumi.Input[str] remote_db_instance_id: The instanceId of the remote instance which provide data.
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[str] user_name: The user name used to connect to the remote instance
        :param pulumi.Input[str] user_password: The user password used to connect to the remote instance
        """
        if data_source_name is not None:
            pulumi.set(__self__, "data_source_name", data_source_name)
        if local_database is not None:
            pulumi.set(__self__, "local_database", local_database)
        if local_db_instance_id is not None:
            pulumi.set(__self__, "local_db_instance_id", local_db_instance_id)
        if manager_user_name is not None:
            pulumi.set(__self__, "manager_user_name", manager_user_name)
        if manager_user_password is not None:
            pulumi.set(__self__, "manager_user_password", manager_user_password)
        if remote_adb_data_source_id is not None:
            pulumi.set(__self__, "remote_adb_data_source_id", remote_adb_data_source_id)
        if remote_database is not None:
            pulumi.set(__self__, "remote_database", remote_database)
        if remote_db_instance_id is not None:
            pulumi.set(__self__, "remote_db_instance_id", remote_db_instance_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if user_password is not None:
            pulumi.set(__self__, "user_password", user_password)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> Optional[pulumi.Input[str]]:
        """
        Data Source Name
        """
        return pulumi.get(self, "data_source_name")

    @data_source_name.setter
    def data_source_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_name", value)

    @property
    @pulumi.getter(name="localDatabase")
    def local_database(self) -> Optional[pulumi.Input[str]]:
        """
        The database of the local instance which connection data.
        """
        return pulumi.get(self, "local_database")

    @local_database.setter
    def local_database(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_database", value)

    @property
    @pulumi.getter(name="localDbInstanceId")
    def local_db_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The instanceId of the local instance which connection data.
        """
        return pulumi.get(self, "local_db_instance_id")

    @local_db_instance_id.setter
    def local_db_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_db_instance_id", value)

    @property
    @pulumi.getter(name="managerUserName")
    def manager_user_name(self) -> Optional[pulumi.Input[str]]:
        """
        The Management user name of the local instance.
        """
        return pulumi.get(self, "manager_user_name")

    @manager_user_name.setter
    def manager_user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manager_user_name", value)

    @property
    @pulumi.getter(name="managerUserPassword")
    def manager_user_password(self) -> Optional[pulumi.Input[str]]:
        """
        Password of the Manager user of the local instance
        """
        return pulumi.get(self, "manager_user_password")

    @manager_user_password.setter
    def manager_user_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manager_user_password", value)

    @property
    @pulumi.getter(name="remoteAdbDataSourceId")
    def remote_adb_data_source_id(self) -> Optional[pulumi.Input[int]]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "remote_adb_data_source_id")

    @remote_adb_data_source_id.setter
    def remote_adb_data_source_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "remote_adb_data_source_id", value)

    @property
    @pulumi.getter(name="remoteDatabase")
    def remote_database(self) -> Optional[pulumi.Input[str]]:
        """
        The database of the remote instance which provide data.
        """
        return pulumi.get(self, "remote_database")

    @remote_database.setter
    def remote_database(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remote_database", value)

    @property
    @pulumi.getter(name="remoteDbInstanceId")
    def remote_db_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The instanceId of the remote instance which provide data.
        """
        return pulumi.get(self, "remote_db_instance_id")

    @remote_db_instance_id.setter
    def remote_db_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remote_db_instance_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[str]]:
        """
        The user name used to connect to the remote instance
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> Optional[pulumi.Input[str]]:
        """
        The user password used to connect to the remote instance
        """
        return pulumi.get(self, "user_password")

    @user_password.setter
    def user_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_password", value)


class RemoteAdbDataSource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_source_name: Optional[pulumi.Input[str]] = None,
                 local_database: Optional[pulumi.Input[str]] = None,
                 local_db_instance_id: Optional[pulumi.Input[str]] = None,
                 manager_user_name: Optional[pulumi.Input[str]] = None,
                 manager_user_password: Optional[pulumi.Input[str]] = None,
                 remote_database: Optional[pulumi.Input[str]] = None,
                 remote_db_instance_id: Optional[pulumi.Input[str]] = None,
                 user_name: Optional[pulumi.Input[str]] = None,
                 user_password: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a GPDB Remote A D B Data Source resource.

        RemoteADBDataSource is the data external table call method between greenplums, which will be used for data external table access between ADB-PG.

        For information about GPDB Remote A D B Data Source and how to use it, see [What is Remote A D B Data Source](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.227.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        default4_mf0n_y = alicloud.vpc.Network("default4Mf0nY", cidr_block="192.168.0.0/16")
        defaultw_sa_vpf = alicloud.vpc.Switch("defaultwSAVpf",
            vpc_id=default4_mf0n_y.id,
            zone_id="cn-beijing-h",
            cidr_block="192.168.1.0/24")
        default_et_ez_mf = alicloud.gpdb.Instance("defaultEtEzMF",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=defaultw_sa_vpf.id,
            storage_size=50,
            master_cu=4,
            vpc_id=default4_mf0n_y.id,
            db_instance_mode="StorageElastic",
            engine="gpdb")
        default_ey7t9t = alicloud.gpdb.Instance("defaultEY7t9t",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=defaultw_sa_vpf.id,
            storage_size=50,
            master_cu=4,
            vpc_id=default4_mf0n_y.id,
            db_instance_mode="StorageElastic",
            engine="gpdb")
        default26qp_eo = alicloud.gpdb.Account("default26qpEo",
            account_description="example_001",
            db_instance_id=default_et_ez_mf.id,
            account_name="example_001",
            account_password="example_001")
        defaultw_xe_pof = alicloud.gpdb.Account("defaultwXePof",
            account_description="example_001",
            db_instance_id=default_ey7t9t.id,
            account_name="example_001",
            account_password="example_001")
        default_remote_adb_data_source = alicloud.gpdb.RemoteAdbDataSource("default",
            remote_database="example_001",
            manager_user_name="example_001",
            user_name="example_001",
            remote_db_instance_id=defaultw_xe_pof.db_instance_id,
            local_database="example_001",
            data_source_name="myexample",
            user_password="example_001",
            manager_user_password="example_001",
            local_db_instance_id=default_et_ez_mf.id)
        ```

        ## Import

        GPDB Remote A D B Data Source can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/remoteAdbDataSource:RemoteAdbDataSource example <local_db_instance_id>:<remote_adb_data_source_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] data_source_name: Data Source Name
        :param pulumi.Input[str] local_database: The database of the local instance which connection data.
        :param pulumi.Input[str] local_db_instance_id: The instanceId of the local instance which connection data.
        :param pulumi.Input[str] manager_user_name: The Management user name of the local instance.
        :param pulumi.Input[str] manager_user_password: Password of the Manager user of the local instance
        :param pulumi.Input[str] remote_database: The database of the remote instance which provide data.
        :param pulumi.Input[str] remote_db_instance_id: The instanceId of the remote instance which provide data.
        :param pulumi.Input[str] user_name: The user name used to connect to the remote instance
        :param pulumi.Input[str] user_password: The user password used to connect to the remote instance
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RemoteAdbDataSourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a GPDB Remote A D B Data Source resource.

        RemoteADBDataSource is the data external table call method between greenplums, which will be used for data external table access between ADB-PG.

        For information about GPDB Remote A D B Data Source and how to use it, see [What is Remote A D B Data Source](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.227.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        default4_mf0n_y = alicloud.vpc.Network("default4Mf0nY", cidr_block="192.168.0.0/16")
        defaultw_sa_vpf = alicloud.vpc.Switch("defaultwSAVpf",
            vpc_id=default4_mf0n_y.id,
            zone_id="cn-beijing-h",
            cidr_block="192.168.1.0/24")
        default_et_ez_mf = alicloud.gpdb.Instance("defaultEtEzMF",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=defaultw_sa_vpf.id,
            storage_size=50,
            master_cu=4,
            vpc_id=default4_mf0n_y.id,
            db_instance_mode="StorageElastic",
            engine="gpdb")
        default_ey7t9t = alicloud.gpdb.Instance("defaultEY7t9t",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=defaultw_sa_vpf.id,
            storage_size=50,
            master_cu=4,
            vpc_id=default4_mf0n_y.id,
            db_instance_mode="StorageElastic",
            engine="gpdb")
        default26qp_eo = alicloud.gpdb.Account("default26qpEo",
            account_description="example_001",
            db_instance_id=default_et_ez_mf.id,
            account_name="example_001",
            account_password="example_001")
        defaultw_xe_pof = alicloud.gpdb.Account("defaultwXePof",
            account_description="example_001",
            db_instance_id=default_ey7t9t.id,
            account_name="example_001",
            account_password="example_001")
        default_remote_adb_data_source = alicloud.gpdb.RemoteAdbDataSource("default",
            remote_database="example_001",
            manager_user_name="example_001",
            user_name="example_001",
            remote_db_instance_id=defaultw_xe_pof.db_instance_id,
            local_database="example_001",
            data_source_name="myexample",
            user_password="example_001",
            manager_user_password="example_001",
            local_db_instance_id=default_et_ez_mf.id)
        ```

        ## Import

        GPDB Remote A D B Data Source can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/remoteAdbDataSource:RemoteAdbDataSource example <local_db_instance_id>:<remote_adb_data_source_id>
        ```

        :param str resource_name: The name of the resource.
        :param RemoteAdbDataSourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RemoteAdbDataSourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_source_name: Optional[pulumi.Input[str]] = None,
                 local_database: Optional[pulumi.Input[str]] = None,
                 local_db_instance_id: Optional[pulumi.Input[str]] = None,
                 manager_user_name: Optional[pulumi.Input[str]] = None,
                 manager_user_password: Optional[pulumi.Input[str]] = None,
                 remote_database: Optional[pulumi.Input[str]] = None,
                 remote_db_instance_id: Optional[pulumi.Input[str]] = None,
                 user_name: Optional[pulumi.Input[str]] = None,
                 user_password: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RemoteAdbDataSourceArgs.__new__(RemoteAdbDataSourceArgs)

            __props__.__dict__["data_source_name"] = data_source_name
            if local_database is None and not opts.urn:
                raise TypeError("Missing required property 'local_database'")
            __props__.__dict__["local_database"] = local_database
            if local_db_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'local_db_instance_id'")
            __props__.__dict__["local_db_instance_id"] = local_db_instance_id
            if manager_user_name is None and not opts.urn:
                raise TypeError("Missing required property 'manager_user_name'")
            __props__.__dict__["manager_user_name"] = manager_user_name
            if manager_user_password is None and not opts.urn:
                raise TypeError("Missing required property 'manager_user_password'")
            __props__.__dict__["manager_user_password"] = None if manager_user_password is None else pulumi.Output.secret(manager_user_password)
            if remote_database is None and not opts.urn:
                raise TypeError("Missing required property 'remote_database'")
            __props__.__dict__["remote_database"] = remote_database
            if remote_db_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'remote_db_instance_id'")
            __props__.__dict__["remote_db_instance_id"] = remote_db_instance_id
            if user_name is None and not opts.urn:
                raise TypeError("Missing required property 'user_name'")
            __props__.__dict__["user_name"] = user_name
            if user_password is None and not opts.urn:
                raise TypeError("Missing required property 'user_password'")
            __props__.__dict__["user_password"] = None if user_password is None else pulumi.Output.secret(user_password)
            __props__.__dict__["remote_adb_data_source_id"] = None
            __props__.__dict__["status"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["managerUserPassword", "userPassword"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(RemoteAdbDataSource, __self__).__init__(
            'alicloud:gpdb/remoteAdbDataSource:RemoteAdbDataSource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            data_source_name: Optional[pulumi.Input[str]] = None,
            local_database: Optional[pulumi.Input[str]] = None,
            local_db_instance_id: Optional[pulumi.Input[str]] = None,
            manager_user_name: Optional[pulumi.Input[str]] = None,
            manager_user_password: Optional[pulumi.Input[str]] = None,
            remote_adb_data_source_id: Optional[pulumi.Input[int]] = None,
            remote_database: Optional[pulumi.Input[str]] = None,
            remote_db_instance_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            user_name: Optional[pulumi.Input[str]] = None,
            user_password: Optional[pulumi.Input[str]] = None) -> 'RemoteAdbDataSource':
        """
        Get an existing RemoteAdbDataSource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] data_source_name: Data Source Name
        :param pulumi.Input[str] local_database: The database of the local instance which connection data.
        :param pulumi.Input[str] local_db_instance_id: The instanceId of the local instance which connection data.
        :param pulumi.Input[str] manager_user_name: The Management user name of the local instance.
        :param pulumi.Input[str] manager_user_password: Password of the Manager user of the local instance
        :param pulumi.Input[int] remote_adb_data_source_id: The first ID of the resource
        :param pulumi.Input[str] remote_database: The database of the remote instance which provide data.
        :param pulumi.Input[str] remote_db_instance_id: The instanceId of the remote instance which provide data.
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[str] user_name: The user name used to connect to the remote instance
        :param pulumi.Input[str] user_password: The user password used to connect to the remote instance
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RemoteAdbDataSourceState.__new__(_RemoteAdbDataSourceState)

        __props__.__dict__["data_source_name"] = data_source_name
        __props__.__dict__["local_database"] = local_database
        __props__.__dict__["local_db_instance_id"] = local_db_instance_id
        __props__.__dict__["manager_user_name"] = manager_user_name
        __props__.__dict__["manager_user_password"] = manager_user_password
        __props__.__dict__["remote_adb_data_source_id"] = remote_adb_data_source_id
        __props__.__dict__["remote_database"] = remote_database
        __props__.__dict__["remote_db_instance_id"] = remote_db_instance_id
        __props__.__dict__["status"] = status
        __props__.__dict__["user_name"] = user_name
        __props__.__dict__["user_password"] = user_password
        return RemoteAdbDataSource(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> pulumi.Output[Optional[str]]:
        """
        Data Source Name
        """
        return pulumi.get(self, "data_source_name")

    @property
    @pulumi.getter(name="localDatabase")
    def local_database(self) -> pulumi.Output[str]:
        """
        The database of the local instance which connection data.
        """
        return pulumi.get(self, "local_database")

    @property
    @pulumi.getter(name="localDbInstanceId")
    def local_db_instance_id(self) -> pulumi.Output[str]:
        """
        The instanceId of the local instance which connection data.
        """
        return pulumi.get(self, "local_db_instance_id")

    @property
    @pulumi.getter(name="managerUserName")
    def manager_user_name(self) -> pulumi.Output[str]:
        """
        The Management user name of the local instance.
        """
        return pulumi.get(self, "manager_user_name")

    @property
    @pulumi.getter(name="managerUserPassword")
    def manager_user_password(self) -> pulumi.Output[str]:
        """
        Password of the Manager user of the local instance
        """
        return pulumi.get(self, "manager_user_password")

    @property
    @pulumi.getter(name="remoteAdbDataSourceId")
    def remote_adb_data_source_id(self) -> pulumi.Output[int]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "remote_adb_data_source_id")

    @property
    @pulumi.getter(name="remoteDatabase")
    def remote_database(self) -> pulumi.Output[str]:
        """
        The database of the remote instance which provide data.
        """
        return pulumi.get(self, "remote_database")

    @property
    @pulumi.getter(name="remoteDbInstanceId")
    def remote_db_instance_id(self) -> pulumi.Output[str]:
        """
        The instanceId of the remote instance which provide data.
        """
        return pulumi.get(self, "remote_db_instance_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[str]:
        """
        The user name used to connect to the remote instance
        """
        return pulumi.get(self, "user_name")

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> pulumi.Output[str]:
        """
        The user password used to connect to the remote instance
        """
        return pulumi.get(self, "user_password")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SwarmArgs', 'Swarm']

@pulumi.input_type
class SwarmArgs:
    def __init__(__self__, *,
                 cidr_block: pulumi.Input[str],
                 instance_type: pulumi.Input[str],
                 password: pulumi.Input[str],
                 vswitch_id: pulumi.Input[str],
                 disk_category: Optional[pulumi.Input[str]] = None,
                 disk_size: Optional[pulumi.Input[int]] = None,
                 image_id: Optional[pulumi.Input[str]] = None,
                 is_outdated: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_prefix: Optional[pulumi.Input[str]] = None,
                 need_slb: Optional[pulumi.Input[bool]] = None,
                 node_number: Optional[pulumi.Input[int]] = None,
                 release_eip: Optional[pulumi.Input[bool]] = None,
                 size: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Swarm resource.
        """
        pulumi.set(__self__, "cidr_block", cidr_block)
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        if disk_category is not None:
            pulumi.set(__self__, "disk_category", disk_category)
        if disk_size is not None:
            pulumi.set(__self__, "disk_size", disk_size)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if is_outdated is not None:
            pulumi.set(__self__, "is_outdated", is_outdated)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if name_prefix is not None:
            pulumi.set(__self__, "name_prefix", name_prefix)
        if need_slb is not None:
            pulumi.set(__self__, "need_slb", need_slb)
        if node_number is not None:
            pulumi.set(__self__, "node_number", node_number)
        if release_eip is not None:
            pulumi.set(__self__, "release_eip", release_eip)
        if size is not None:
            warnings.warn("""Field 'size' has been deprecated from provider version 1.9.1. New field 'node_number' replaces it.""", DeprecationWarning)
            pulumi.log.warn("""size is deprecated: Field 'size' has been deprecated from provider version 1.9.1. New field 'node_number' replaces it.""")
        if size is not None:
            pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Input[str]:
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: pulumi.Input[str]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[str]:
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="diskCategory")
    def disk_category(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "disk_category")

    @disk_category.setter
    def disk_category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_category", value)

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "disk_size")

    @disk_size.setter
    def disk_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disk_size", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="isOutdated")
    def is_outdated(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "is_outdated")

    @is_outdated.setter
    def is_outdated(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_outdated", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name_prefix")

    @name_prefix.setter
    def name_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_prefix", value)

    @property
    @pulumi.getter(name="needSlb")
    def need_slb(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "need_slb")

    @need_slb.setter
    def need_slb(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "need_slb", value)

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "node_number")

    @node_number.setter
    def node_number(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "node_number", value)

    @property
    @pulumi.getter(name="releaseEip")
    def release_eip(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "release_eip")

    @release_eip.setter
    def release_eip(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "release_eip", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'size' has been deprecated from provider version 1.9.1. New field 'node_number' replaces it.""")
    def size(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "size", value)


@pulumi.input_type
class _SwarmState:
    def __init__(__self__, *,
                 agent_version: Optional[pulumi.Input[str]] = None,
                 cidr_block: Optional[pulumi.Input[str]] = None,
                 disk_category: Optional[pulumi.Input[str]] = None,
                 disk_size: Optional[pulumi.Input[int]] = None,
                 image_id: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 is_outdated: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_prefix: Optional[pulumi.Input[str]] = None,
                 need_slb: Optional[pulumi.Input[bool]] = None,
                 node_number: Optional[pulumi.Input[int]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input['SwarmNodeArgs']]]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 release_eip: Optional[pulumi.Input[bool]] = None,
                 security_group_id: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 slb_id: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Swarm resources.
        """
        if agent_version is not None:
            pulumi.set(__self__, "agent_version", agent_version)
        if cidr_block is not None:
            pulumi.set(__self__, "cidr_block", cidr_block)
        if disk_category is not None:
            pulumi.set(__self__, "disk_category", disk_category)
        if disk_size is not None:
            pulumi.set(__self__, "disk_size", disk_size)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if is_outdated is not None:
            pulumi.set(__self__, "is_outdated", is_outdated)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if name_prefix is not None:
            pulumi.set(__self__, "name_prefix", name_prefix)
        if need_slb is not None:
            pulumi.set(__self__, "need_slb", need_slb)
        if node_number is not None:
            pulumi.set(__self__, "node_number", node_number)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if release_eip is not None:
            pulumi.set(__self__, "release_eip", release_eip)
        if security_group_id is not None:
            pulumi.set(__self__, "security_group_id", security_group_id)
        if size is not None:
            warnings.warn("""Field 'size' has been deprecated from provider version 1.9.1. New field 'node_number' replaces it.""", DeprecationWarning)
            pulumi.log.warn("""size is deprecated: Field 'size' has been deprecated from provider version 1.9.1. New field 'node_number' replaces it.""")
        if size is not None:
            pulumi.set(__self__, "size", size)
        if slb_id is not None:
            pulumi.set(__self__, "slb_id", slb_id)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="agentVersion")
    def agent_version(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "agent_version")

    @agent_version.setter
    def agent_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "agent_version", value)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter(name="diskCategory")
    def disk_category(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "disk_category")

    @disk_category.setter
    def disk_category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_category", value)

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "disk_size")

    @disk_size.setter
    def disk_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disk_size", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="isOutdated")
    def is_outdated(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "is_outdated")

    @is_outdated.setter
    def is_outdated(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_outdated", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name_prefix")

    @name_prefix.setter
    def name_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_prefix", value)

    @property
    @pulumi.getter(name="needSlb")
    def need_slb(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "need_slb")

    @need_slb.setter
    def need_slb(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "need_slb", value)

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "node_number")

    @node_number.setter
    def node_number(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "node_number", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SwarmNodeArgs']]]]:
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SwarmNodeArgs']]]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="releaseEip")
    def release_eip(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "release_eip")

    @release_eip.setter
    def release_eip(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "release_eip", value)

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "security_group_id")

    @security_group_id.setter
    def security_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_group_id", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'size' has been deprecated from provider version 1.9.1. New field 'node_number' replaces it.""")
    def size(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="slbId")
    def slb_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "slb_id")

    @slb_id.setter
    def slb_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slb_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


class Swarm(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_block: Optional[pulumi.Input[str]] = None,
                 disk_category: Optional[pulumi.Input[str]] = None,
                 disk_size: Optional[pulumi.Input[int]] = None,
                 image_id: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 is_outdated: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_prefix: Optional[pulumi.Input[str]] = None,
                 need_slb: Optional[pulumi.Input[bool]] = None,
                 node_number: Optional[pulumi.Input[int]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 release_eip: Optional[pulumi.Input[bool]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a Swarm resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SwarmArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Swarm resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param SwarmArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SwarmArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_block: Optional[pulumi.Input[str]] = None,
                 disk_category: Optional[pulumi.Input[str]] = None,
                 disk_size: Optional[pulumi.Input[int]] = None,
                 image_id: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 is_outdated: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_prefix: Optional[pulumi.Input[str]] = None,
                 need_slb: Optional[pulumi.Input[bool]] = None,
                 node_number: Optional[pulumi.Input[int]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 release_eip: Optional[pulumi.Input[bool]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SwarmArgs.__new__(SwarmArgs)

            if cidr_block is None and not opts.urn:
                raise TypeError("Missing required property 'cidr_block'")
            __props__.__dict__["cidr_block"] = cidr_block
            __props__.__dict__["disk_category"] = disk_category
            __props__.__dict__["disk_size"] = disk_size
            __props__.__dict__["image_id"] = image_id
            if instance_type is None and not opts.urn:
                raise TypeError("Missing required property 'instance_type'")
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["is_outdated"] = is_outdated
            __props__.__dict__["name"] = name
            __props__.__dict__["name_prefix"] = name_prefix
            __props__.__dict__["need_slb"] = need_slb
            __props__.__dict__["node_number"] = node_number
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["release_eip"] = release_eip
            __props__.__dict__["size"] = size
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["agent_version"] = None
            __props__.__dict__["nodes"] = None
            __props__.__dict__["security_group_id"] = None
            __props__.__dict__["slb_id"] = None
            __props__.__dict__["vpc_id"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Swarm, __self__).__init__(
            'alicloud:cs/swarm:Swarm',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agent_version: Optional[pulumi.Input[str]] = None,
            cidr_block: Optional[pulumi.Input[str]] = None,
            disk_category: Optional[pulumi.Input[str]] = None,
            disk_size: Optional[pulumi.Input[int]] = None,
            image_id: Optional[pulumi.Input[str]] = None,
            instance_type: Optional[pulumi.Input[str]] = None,
            is_outdated: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            name_prefix: Optional[pulumi.Input[str]] = None,
            need_slb: Optional[pulumi.Input[bool]] = None,
            node_number: Optional[pulumi.Input[int]] = None,
            nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SwarmNodeArgs', 'SwarmNodeArgsDict']]]]] = None,
            password: Optional[pulumi.Input[str]] = None,
            release_eip: Optional[pulumi.Input[bool]] = None,
            security_group_id: Optional[pulumi.Input[str]] = None,
            size: Optional[pulumi.Input[int]] = None,
            slb_id: Optional[pulumi.Input[str]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None) -> 'Swarm':
        """
        Get an existing Swarm resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SwarmState.__new__(_SwarmState)

        __props__.__dict__["agent_version"] = agent_version
        __props__.__dict__["cidr_block"] = cidr_block
        __props__.__dict__["disk_category"] = disk_category
        __props__.__dict__["disk_size"] = disk_size
        __props__.__dict__["image_id"] = image_id
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["is_outdated"] = is_outdated
        __props__.__dict__["name"] = name
        __props__.__dict__["name_prefix"] = name_prefix
        __props__.__dict__["need_slb"] = need_slb
        __props__.__dict__["node_number"] = node_number
        __props__.__dict__["nodes"] = nodes
        __props__.__dict__["password"] = password
        __props__.__dict__["release_eip"] = release_eip
        __props__.__dict__["security_group_id"] = security_group_id
        __props__.__dict__["size"] = size
        __props__.__dict__["slb_id"] = slb_id
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_id"] = vswitch_id
        return Swarm(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="agentVersion")
    def agent_version(self) -> pulumi.Output[str]:
        return pulumi.get(self, "agent_version")

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Output[str]:
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter(name="diskCategory")
    def disk_category(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "disk_category")

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "disk_size")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[str]:
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="isOutdated")
    def is_outdated(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "is_outdated")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "name_prefix")

    @property
    @pulumi.getter(name="needSlb")
    def need_slb(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "need_slb")

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "node_number")

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[Sequence['outputs.SwarmNode']]:
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[str]:
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="releaseEip")
    def release_eip(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "release_eip")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'size' has been deprecated from provider version 1.9.1. New field 'node_number' replaces it.""")
    def size(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="slbId")
    def slb_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "slb_id")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "vswitch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBgpPeersResult',
    'AwaitableGetBgpPeersResult',
    'get_bgp_peers',
    'get_bgp_peers_output',
]

@pulumi.output_type
class GetBgpPeersResult:
    """
    A collection of values returned by getBgpPeers.
    """
    def __init__(__self__, bgp_group_id=None, id=None, ids=None, output_file=None, peers=None, router_id=None, status=None):
        if bgp_group_id and not isinstance(bgp_group_id, str):
            raise TypeError("Expected argument 'bgp_group_id' to be a str")
        pulumi.set(__self__, "bgp_group_id", bgp_group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if peers and not isinstance(peers, list):
            raise TypeError("Expected argument 'peers' to be a list")
        pulumi.set(__self__, "peers", peers)
        if router_id and not isinstance(router_id, str):
            raise TypeError("Expected argument 'router_id' to be a str")
        pulumi.set(__self__, "router_id", router_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="bgpGroupId")
    def bgp_group_id(self) -> Optional[str]:
        return pulumi.get(self, "bgp_group_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def peers(self) -> Sequence['outputs.GetBgpPeersPeerResult']:
        return pulumi.get(self, "peers")

    @property
    @pulumi.getter(name="routerId")
    def router_id(self) -> Optional[str]:
        return pulumi.get(self, "router_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetBgpPeersResult(GetBgpPeersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBgpPeersResult(
            bgp_group_id=self.bgp_group_id,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            peers=self.peers,
            router_id=self.router_id,
            status=self.status)


def get_bgp_peers(bgp_group_id: Optional[str] = None,
                  ids: Optional[Sequence[str]] = None,
                  output_file: Optional[str] = None,
                  router_id: Optional[str] = None,
                  status: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBgpPeersResult:
    """
    This data source provides the Vpc Bgp Peers of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.153.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_bgp_peers(ids=[
        "example_value-1",
        "example_value-2",
    ])
    pulumi.export("vpcBgpPeerId1", ids.peers[0].id)
    bgp_group_id = alicloud.vpc.get_bgp_peers(bgp_group_id="example_value")
    pulumi.export("vpcBgpPeerId2", bgp_group_id.peers[0].id)
    router_id = alicloud.vpc.get_bgp_peers(router_id="example_value")
    pulumi.export("vpcBgpPeerId3", router_id.peers[0].id)
    status = alicloud.vpc.get_bgp_peers(status="Available")
    pulumi.export("vpcBgpPeerId4", status.peers[0].id)
    ```


    :param str bgp_group_id: The ID of the BGP group to which the BGP peer that you want to query belongs.
    :param Sequence[str] ids: A list of Bgp Peer IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str router_id: The ID of the virtual border router (VBR) that is associated with the BGP peer that you want to query.
    :param str status: The status of the BGP peer. Valid values: `Available`, `Deleted`, `Deleting`, `Modifying`, `Pending`.
    """
    __args__ = dict()
    __args__['bgpGroupId'] = bgp_group_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['routerId'] = router_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getBgpPeers:getBgpPeers', __args__, opts=opts, typ=GetBgpPeersResult).value

    return AwaitableGetBgpPeersResult(
        bgp_group_id=pulumi.get(__ret__, 'bgp_group_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        peers=pulumi.get(__ret__, 'peers'),
        router_id=pulumi.get(__ret__, 'router_id'),
        status=pulumi.get(__ret__, 'status'))
def get_bgp_peers_output(bgp_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                         ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                         output_file: Optional[pulumi.Input[Optional[str]]] = None,
                         router_id: Optional[pulumi.Input[Optional[str]]] = None,
                         status: Optional[pulumi.Input[Optional[str]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBgpPeersResult]:
    """
    This data source provides the Vpc Bgp Peers of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.153.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_bgp_peers(ids=[
        "example_value-1",
        "example_value-2",
    ])
    pulumi.export("vpcBgpPeerId1", ids.peers[0].id)
    bgp_group_id = alicloud.vpc.get_bgp_peers(bgp_group_id="example_value")
    pulumi.export("vpcBgpPeerId2", bgp_group_id.peers[0].id)
    router_id = alicloud.vpc.get_bgp_peers(router_id="example_value")
    pulumi.export("vpcBgpPeerId3", router_id.peers[0].id)
    status = alicloud.vpc.get_bgp_peers(status="Available")
    pulumi.export("vpcBgpPeerId4", status.peers[0].id)
    ```


    :param str bgp_group_id: The ID of the BGP group to which the BGP peer that you want to query belongs.
    :param Sequence[str] ids: A list of Bgp Peer IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str router_id: The ID of the virtual border router (VBR) that is associated with the BGP peer that you want to query.
    :param str status: The status of the BGP peer. Valid values: `Available`, `Deleted`, `Deleting`, `Modifying`, `Pending`.
    """
    __args__ = dict()
    __args__['bgpGroupId'] = bgp_group_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['routerId'] = router_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getBgpPeers:getBgpPeers', __args__, opts=opts, typ=GetBgpPeersResult)
    return __ret__.apply(lambda __response__: GetBgpPeersResult(
        bgp_group_id=pulumi.get(__response__, 'bgp_group_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        peers=pulumi.get(__response__, 'peers'),
        router_id=pulumi.get(__response__, 'router_id'),
        status=pulumi.get(__response__, 'status')))
